# spaudiopy
Spatial Audio Python Package.

The focus (so far) is on spatial audio decoders.
The package includes e.g. spherical harmonics processing and (binaural renderings of) loudspeaker decoders, such as VBAP and ALLRAD.

# Documentation
You can find the latest package documentation here:  
https://spaudiopy.readthedocs.io/

# Quickstart
It's easiest to start with something like [Anaconda](https://www.anaconda.com/distribution/) as a Python distribution.
You'll need Python >= 3.6 .

You can simply install via pip:  
  `pip install spaudiopy`
  
   
If you want to go into detail and install from source:

1. Create a conda environment:  
  `conda create --name spaudio python=3.6 anaconda joblib`
2. Activate this new environment:  
  `conda activate spaudio`
  
Install the package and remaining dependencies:  
  `pip install -e . ` 


Licence
-------
MIT -- see the file LICENSE for details.

Contributions
-------------
This is meant to be an open project and contributions or feature requests are always welcome!
